apnspy
======

.. image:: 	https://img.shields.io/pypi/pyversions/apnspy.svg
    :target: https://github.com/yehchilai/apnspy
.. image:: https://travis-ci.org/yehchilai/apnspy.svg?branch=master
    :target: https://travis-ci.org/yehchilai/apnspy
.. image:: https://img.shields.io/pypi/v/apnspy.svg?
   :target: http://badge.fury.io/py/apnspy
.. image:: https://img.shields.io/hexpm/l/plug.svg
   :target: https://github.com/yehchilai/apnspy/blob/master/LICENSE

A Python client for Apple Push Notification service

For more information, please read the `document`_

Quick Start
-----------

Use ``pip`` to install.

.. code-block:: bash

    $ pip install apnspy


(Optional) creat a virtual environment and use ``pip`` to install

.. code-block:: bash

    $ virtualenv venv
    $ source venv/bin/activate
    (venv) $ pip install apnspy

Check if the package is installed.

.. code-block:: bash

    $ python
    >>> from apnspy import APNs
    >>>
    
There should be no ImportError.

.. _document: https://apnspy.readthedocs.io/en/latest/

